==> contextly-6.x-1.1.tar.gz: contextly/js/contextly-edit-form.js <==
(function ($) {

  var links = function() {
    return $('a.contextly-popup-link');
  };

  var onSettingsLoaded = function () {
    links()
      .unbind('click.contextly')
      .bind('click.contextly', function () {
        // Open popup and just reload settings on any message from the server.
        Drupal.contextly.editor.open('general');
        return false;
      })
      .text(Drupal.t('Open Contextly editor'));
  };

  var onSettingsFailed = function () {
    links()
      .unbind('click.contextly')
      .bind('click.contextly', function () {
        Drupal.contextly.editor.loadSettings();
        return false;
      })
      .text(Drupal.t('Unable to load settings from Contextly. Click to try again.'));
  };

  var onSettingsLoading = function () {
    links()
      .unbind('click.contextly')
      .bind('click.contextly', function () {
        return false;
      })
      .text(Drupal.t('Loading...'));
  };

  Drupal.behaviors.contextlyEditForm = function (context) {
    // React to the window events. Attach only once for the page.
    var markerClass = 'contextly-edit-form-processed';
    $('body:not(.' + markerClass + ')', context)
      .addClass(markerClass)
      .each(function() {
        $(window)
          .bind('contextlySettingsLoading', onSettingsLoading)
          .bind('contextlySettingsLoaded', onSettingsLoaded)
          .bind('contextlySettingsFailed', onSettingsFailed);

        // In case the popup has been attached before this one we need to check
        // its stage and change the state of the links.
        if (Drupal.contextly.editor.isLoading) {
          links().each(onSettingsLoading);
        }
      });
  };

})(jQuery);

==> contextly-6.x-1.3.tar.gz: contextly/js/contextly-edit-form.js <==
(function ($) {

  var links = function() {
    return $('a.contextly-popup-link');
  };

  var onSettingsLoaded = function () {
    links()
      .unbind('click.contextly')
      .bind('click.contextly', function () {
        // Open popup and just reload settings on any message from the server.
        Contextly.editor.open('snippet');
        return false;
      })
      .text(Drupal.t('Open Contextly editor'));
  };

  var onSettingsFailed = function () {
    links()
      .unbind('click.contextly')
      .bind('click.contextly', function () {
        Contextly.editor.loadSettings();
        return false;
      })
      .text(Drupal.t('Unable to load settings from Contextly. Click to try again.'));
  };

  var onSettingsLoading = function () {
    links()
      .unbind('click.contextly')
      .bind('click.contextly', function () {
        return false;
      })
      .text(Drupal.t('Loading...'));
  };

  Drupal.behaviors.contextlyEditForm = function (context) {
    // React to the window events. Attach only once for the page.
    var markerClass = 'contextly-edit-form-processed';
    $('body:not(.' + markerClass + ')', context)
      .addClass(markerClass)
      .each(function() {
        $(window)
          .bind('contextlySettingsLoading', onSettingsLoading)
          .bind('contextlySettingsLoaded', onSettingsLoaded)
          .bind('contextlySettingsFailed', onSettingsFailed);

        // In case the popup has been attached before this one we need to check
        // its stage and change the state of the links.
        if (Contextly.editor.isLoading) {
          links().each(onSettingsLoading);
        }
      });
  };

})(jQuery);
